@@ -16,7 +16,9 @@ class diglot:
 import akara
 from akamu.diglot import Manager
 
-def GetDiglotManager(graphUriFn):
+def GetDiglotManager(graphUriFn=None):
+    if graphUriFn is None:
+        graphUriFn = akara.module_config().get('graphUriFn')
     rootPath       = akara.module_config().get('rootPath')
     datasetName    = akara.module_config().get('datasetName')
     transforms4Dir = akara.module_config().get('transforms4Dir',{})
