@@ -30,5 +30,5 @@ def ReverseTransform(graph):
     return src.getvalue()
 
 @service(SERVICE_ID, 'diglot')
-@grddl_graphstore_resource('/diglot', TestGraphUriFn, caching = True)
+@grddl_graphstore_resource('/diglot', TestGraphUriFn, caching = False)
 def grddl_graphstore_protocol(): pass
\ No newline at end of file
